### Name: ContingencyTests
### Title: Independence in Three-Way Contingency Tables
### Aliases: chisq_test chisq_test.formula chisq_test.table
###   chisq_test.IndependenceProblem cmh_test.formula cmh_test.table
###   cmh_test.IndependenceProblem cmh_test lbl_test.formula lbl_test.table
###   lbl_test.IndependenceProblem lbl_test
### Keywords: htest

### ** Examples


## Don't show: 
    set.seed(290875)
## End Don't show

data(jobsatisfaction, package = "coin")

### for females only
chisq_test(as.table(jobsatisfaction[,,"Female"]), 
    distribution = approximate(B = 9999))

### both Income and Job.Satisfaction unordered
cmh_test(jobsatisfaction)

### both Income and Job.Satisfaction ordered, default scores
lbl_test(jobsatisfaction)

### both Income and Job.Satisfaction ordered, alternative scores
lbl_test(jobsatisfaction, scores = list(Job.Satisfaction = c(1, 3, 4, 5),
                                        Income = c(3, 10, 20, 35)))

### the same, null distribution approximated
cmh_test(jobsatisfaction, scores = list(Job.Satisfaction = c(1, 3, 4, 5),
                                        Income = c(3, 10, 20, 35)),
         distribution = approximate(B = 10000))

### Smoking and HDL cholesterin status
### (from Jeong, Jhun and Kim, 2005, CSDA 48, 623-631, Table 2)
smokingHDL <- as.table(
    matrix(c(15,  8, 11,  5, 
              3,  4,  6,  1, 
              6,  7, 15, 11, 
              1,  2,  3,  5), ncol = 4,
           dimnames = list(smoking = c("none", "< 5", "< 10", ">=10"), 
                           HDL = c("normal", "low", "borderline", "abnormal"))
    ))
### use interval mid-points as scores for smoking
lbl_test(smokingHDL, scores = list(smoking = c(0, 2.5, 7.5, 15)))




